#ifndef LYMARK_DNET_H
#define LYMARK_DNET_H

#include <QString>
#include <QByteArray>
#include <QList>

// 初始化错误代码
#define INIT_NO_ERROR					0		// 初始化成功
#define INIT_CTRL_BOARD_OPEN_ERROR		1		// 打开控制板失败
#define INIT_CTRL_BOARD_MEM_ERROR		2		// 控制板内存不足
#define INIT_CTRL_BOARD_THREAD_ERROR	3		// 控制板启动线程失败
#define INIT_LASER_CALIB_ERROR			4		// 激光校正失败
#define INIT_INFRARED_CALIB_ERROR		5		// 红光校正失败
#define INIT_LASER_DRIVER_CALIB_ERROR	6		// 激光器参数设置失败
#define INIT_IO_CONFIG_ERROR			7		// IO配置失败

// 初始化控制卡
// 返回值：成功返回0，错误返回初始化错误代码
typedef int (*f_lm_init)();
extern "C" Q_DECL_EXPORT int lm_init();

// 关闭控制卡
typedef void (*f_lm_destruct)();
extern "C" Q_DECL_EXPORT void lm_destruct();

// 打开文档
// path：文档路径
// 返回值：0=成功，1=路径为空，2=文档不存在，3=打开文档失败
typedef int (*f_lm_openDocument)(const QString &path);
extern "C" Q_DECL_EXPORT int lm_openDocument(const QString &path);

typedef void (*f_lm_get_entities)(QStringList &names);
extern "C" Q_DECL_EXPORT void lm_get_entities(QStringList &names);

// 获取对象内容
// name：对象名称
// text：返回的对象内容
typedef void (*f_lm_get_text)(const QString &name,QString &text);
extern "C" Q_DECL_EXPORT void lm_get_text(const QString &name,QString &text);

// 设置对象内容
// name：对象名称
// text：对象内容
// 返回值：true=成功，false=失败
typedef bool (*f_lm_set_text)(const QString &name,const QString &text);
extern "C" Q_DECL_EXPORT bool lm_set_text(const QString &name,const QString &text);

// 设置对象内容
// name：对象名称
// index: 组合文本/条形码/二维码的子条目序号，数值从1开始计算
// text：对象内容
// 返回值：true=成功，false=失败
typedef bool (*f_lm_set_text_at)(const QString &name,int index,const QString &text);
extern "C" Q_DECL_EXPORT bool lm_set_text_at(const QString &name,int index,const QString &text);

// 打标错误代码
#define MARK_NO_ERROR						0			// 打标正常
#define MARK_OCCUR_ERROR					1			// 打标出现错误
#define MARK_NO_PRINT_OBJECT				2			// 文档没有可打标的对象
#define MARK_NO_PRINT_DATA					3			// 文档没有可打标数据
#define MARK_START_ERROR					4			// 开始打标失败
#define MARK_STOP_ERROR						5			// 停止失败
#define MARK_SN_END							6			// 无循环的序列号已打标完
#define MARK_DB_END							7			// 无循环的数据库已打标完
#define MARK_COUNTER_END					8			// 文档计划个数已全部完成
#define MARK_GEOMETRY_OUT_OF_RANGE			9			// 打标内容超出振镜范围
#define MARK_MIN_SPEED_OVERFLOW				10			// 打标速度小于最小设置速度
#define MARK_MAX_SPEED_OVERFLOW				11			// 打标速度大于最小设置速度
#define MARK_IO_FORBID_ERROR				12			// IO禁止打标中
#define MARK_REPEAT_WITHOUT_BREAK_LARGER	13			// 重复无间隔打标不支持大数据
#define MARK_FREQ_OUT_OF_RANGE				14			// 频率超出范围
#define MARK_INITIAL_ANALOG_POWER_ERROR		15			// 初始化模拟激光器功率失败
#define MARK_SYNC_OUTER_KEY_TRIGGER_ERROR	16			// 同步触发器IO到脚踏信号IO失败
#define MARK_NO_ACTIVE_DOCUMENT				17			// 没有打开文档
#define MARK_NO_FOUND_ENTITY				18			// 没有找到要打标的对象

// 开始打标
// 返回值：成功返回0，错误返回打标错误代码
typedef int (*f_lm_startMark)();
extern "C" Q_DECL_EXPORT int lm_startMark();

// 选择打标名称为name的对象
// 返回值：成功返回0，错误返回打标错误代码
typedef int (*f_lm_startMarkEntity)(const QString &name);
extern "C" Q_DECL_EXPORT int lm_startMarkEntity(const QString &name);

// 文档变换（偏移+旋转）打标
// 返回值：成功返回0，错误返回打标错误代码
// 此指令仅在打标的时候起效果，在打标停止/文档关闭/打标出现错误后文档自动恢复打标前偏移和角度
typedef int (*f_lm_startTransformMarkDoc)(const QList<double> &offsetXs,const QList<double> &offsetYs,const QList<double> &angles);
extern "C" Q_DECL_EXPORT int lm_startTransformMarkDoc(const QList<double> &offsetXs,const QList<double> &offsetYs,const QList<double> &angles);

// 红光预览
// 返回值：成功返回0，错误返回打标错误代码
typedef int (*f_lm_startInfraredPreview)();
extern "C" Q_DECL_EXPORT int lm_startInfraredPreview();

// 停止打标
// 返回值：成功返回true，失败返回false
typedef bool (*f_lm_stopPrint)();
extern "C" Q_DECL_EXPORT bool lm_stopPrint();

// 设置打标完成通知回调函数
typedef void (*lm_mark_finish_callback)(int finishedCount,double time);
typedef void (*f_lm_set_mark_finish_func)(lm_mark_finish_callback);
extern "C" Q_DECL_EXPORT void lm_set_mark_finish_func(lm_mark_finish_callback func);

// 设置打标状态变化回调函数
// status：打标状态,0=停止状态，1=打标中，2=红光预览中
typedef void (*lm_mark_status_callback)(int status);
typedef void (*f_lm_set_mark_status_func)(lm_mark_status_callback);
extern "C" Q_DECL_EXPORT void lm_set_mark_status_func(lm_mark_status_callback func);

// 读取板卡唯一ID号
typedef void (*f_lm_read_board_id)(QByteArray &idBytes);
extern "C" Q_DECL_EXPORT void lm_read_board_id(QByteArray &idBytes);

#endif // LYMARK_DNET_H
